| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | lambda.cu | 17 __host__ __device__ void hd(int x); 23 [=](){ hd(b); }(); in test() 25 [&](){ hd(b); }(); in test() 27 kernel<<<1,1>>>([](){ hd(0); }); in test() 29 kernel<<<1,1>>>([=](){ hd(b); }); in test() 32 kernel<<<1,1>>>([&](){ hd(b); }); in test() 39 auto f = [&]{ hd(b); }; in test() 55 [&](){ hd(b); }(); in main() 57 [=, &b](){ hd(b); }(); in main() 61 kernel<<<1,1>>>([](){ hd(0); }); in main() [all …]
|
| H A D | bad-calls-on-same-line.cu | 29 inline __host__ __device__ void hd() { in hd() function 35 hd<int>(); in host_fn() 36 hd<double>(); in host_fn() 38 hd<float>(); in host_fn()
|
| H A D | call-device-fn-from-host.cu | 23 __host__ __device__ void hd() { device_fn(); } in hd() function 45 __host__ __device__ void hd() { device_fn(); } in hd() function 70 t.hd(); in hd_member_fn()
|
| H A D | call-host-fn-from-device.cu | 23 __host__ __device__ void hd() { host_fn(); } in hd() function 62 __host__ __device__ void hd() { host_fn(); } in hd() function 96 t.hd(); in hd_member_fn()
|
| H A D | vla.cu | 21 __host__ __device__ void hd(int n) { in hd() function
|
| /llvm-project-15.0.7/llvm/test/Analysis/MustExecute/ |
| H A D | must_be_executed_context.ll | 398 ; MBEC-NEXT: -- Explore context of: br i1 %tmp3, label %ex, label %hd 443 ; MBEC-NEXT: -- Explore context of: br i1 %tmp9, label %ex, label %hd 453 br i1 %tmp3, label %ex, label %hd 459 hd: 460 %tmp7 = phi i32 [ %tmp8, %hd ], [ 0, %en ] 464 br i1 %tmp9, label %ex, label %hd 473 ; MBEC-NEXT: -- Explore context of: br i1 %tmp3, label %ex, label %hd 540 br i1 %tmp3, label %ex, label %hd 546 hd: 547 %tmp7 = phi i32 [ %tmp8, %hd ], [ 0, %en ] [all …]
|
| /llvm-project-15.0.7/llvm/test/CodeGen/X86/GC/ |
| H A D | badwriteproto.ll | 9 define ptr @cons(i32 %hd, ptr %tl) gc "example" { 12 store i32 %hd, ptr %tmp
|
| H A D | badreadproto.ll | 10 %hd = call ptr @llvm.gcread(ptr %l, ptr %l)
|
| /llvm-project-15.0.7/libc/src/__support/FPUtil/generic/ |
| H A D | FMod.h | 196 intU_t hd = in execute() local 199 m_x -= hd * m_y; in execute() 203 intU_t hd = (m_x * inv_hy) >> (FPB::FloatProp::BIT_WIDTH - exp_diff); in execute() local 205 m_x -= hd * m_y; in execute()
|
| /llvm-project-15.0.7/llvm/test/Transforms/FunctionAttrs/ |
| H A D | nonnull.ll | 571 ; FNATTR: hd: 581 br i1 %tmp3, label %ex, label %hd 587 hd: 592 br i1 %tmp9, label %ex, label %hd 604 ; FNATTR: hd: 616 br i1 %tmp3, label %ex, label %hd 622 hd: 642 ; FNATTR: hd: 658 hd: 675 ; FNATTR: hd: [all …]
|
| /llvm-project-15.0.7/llvm/test/CodeGen/ARM/ |
| H A D | 2009-02-16-SpillerBug.ll | 18 define fastcc void @FlushGalley(%struct.rec* %hd) nounwind { 91 %1 = icmp eq %struct.rec* %link.1, %hd ; <i1> [#uses=1] 98 …call fastcc void @Promote(%struct.rec* %hd, %struct.rec* %stop_link.3, %struct.rec* null, i32 1) n…
|
| /llvm-project-15.0.7/clang/test/Sema/ |
| H A D | attr-flag-enum.c | 41 hd = ~0x2, // no-warning enumerator
|
| /llvm-project-15.0.7/llvm/test/Transforms/Attributor/ |
| H A D | nonnull.ll | 1137 ; IS________OPM: hd: 1153 ; IS__TUNIT_NPM: hd: 1169 ; IS__CGSCC_NPM: hd: 1184 hd: 1203 ; IS________OPM: hd: 1221 ; IS__TUNIT_NPM: hd: 1239 ; IS__CGSCC_NPM: hd: 1256 hd: 1278 ; NOT_CGSCC_NPM: hd: 1309 hd: [all …]
|
| /llvm-project-15.0.7/clang/test/CXX/special/class.copy/ |
| H A D | implicit-move.cpp | 64 HasDestructor hd; in test_basic_exclusion() local 65 static_assert(!noexcept(hd = HasDestructor()), ""); in test_basic_exclusion()
|
| /llvm-project-15.0.7/clang/test/ARCMT/ |
| H A D | objcmt-subscripting-literals.m.result | 155 void *hd; 156 o = ((NSArray*)hd)[2];
|
| H A D | objcmt-subscripting-literals.m | 155 void *hd; 156 o = [(NSArray*)hd objectAtIndex:2];
|
| /llvm-project-15.0.7/llvm/test/CodeGen/Mips/ |
| H A D | stchar.ll | 4 @.str = private unnamed_addr constant [9 x i8] c"%hd %c \0A\00", align 1
|
| /llvm-project-15.0.7/llvm/lib/Target/ARM/ |
| H A D | ARMScheduleA57.td | 1147 def : InstRW<[A57Write_3cyc_1V], (instregex "VABS(fd|fq|hd|hq)")>; 1150 def : InstRW<[A57Write_5cyc_1V], (instregex "VABD(fd|fq|hd|hq)", 1151 "VADD(fd|fq|hd|hq)", "VPADD(f|h)", "VSUB(fd|fq|hd|hq)")>; 1157 "VC(EQ|GE|GT|LE)(fd|fq|hd|hq)")>; 1173 "(VMAX|VMIN)(fd|fq|hd|hq)", "(VPMAX|VPMIN)(f|h)", "(NEON|VFP)_VMAXNM", 1178 def : InstRW<[A57WriteVMUL_VecFP], (instregex "VMUL(sl)?(fd|fq|hd|hq)")>; 1185 (instregex "(VMLA|VMLS)(sl)?(fd|fq|hd|hq)", "(VFMA|VFMS)(fd|fq|hd|hq)")>; 1188 def : InstRW<[A57Write_3cyc_1V], (instregex "VNEG(fd|f32q|hd|hq)")>;
|
| H A D | ARMScheduleR52.td | 521 def : InstRW<[R52WriteFPALU_F5, R52Read_F1, R52Read_F1], (instregex "VABD(fd|hd)")>; 525 def : InstRW<[R52WriteFPALU_F5, R52Read_F1], (instregex "VABS(fd|hd)")>; 528 def : InstRW<[R52WriteFPALU_F3, R52Read_F1, R52Read_F1], (instregex "(VACGE|VACGT)(fd|hd)")>; 531 def : InstRW<[R52WriteFPALU_F5, R52Read_F1, R52Read_F1], (instregex "(VADD|VSUB)(D|S|H|fd|hd)$")>;
|
| /llvm-project-15.0.7/clang/test/FixIt/ |
| H A D | format.m | 317 // CHECK: fix-it:"{{.*}}":{[[@LINE-1]]:11-[[@LINE-1]]:13}:"%hd"
|
| /llvm-project-15.0.7/clang/include/clang/Basic/ |
| H A D | arm_sve.td | 1805 def SVQXTNB_S : SInst<"svqxtnb[_{d}]", "hd", "sil", MergeNone, "aarch64_sve_sqxtnb">; 1806 def SVQXTNB_U : SInst<"svqxtnb[_{d}]", "hd", "UsUiUl", MergeNone, "aarch64_sve_uqxtnb">;
|